==> jumbo-news-0.9-48.tar.gz: jumbo-news-0.9-48/news/admin.py <==
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from jumbo.admin.options import ExtendibleModelAdmin, OrderedModelAdmin, SettingsAdmin
from jumbo.forms.models import AdminModelForm
from news.models import News, Category, NewsTranslation

class CategoryAdminForm(AdminModelForm):
    class Meta:
        model = Category
class CategoryAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = ('get_status_icon','name','get_edit_icon', 'get_detail_icon', 'get_delete_icon')
    model = Category
    save_on_top = True
    form = CategoryAdminForm
    search_fields = ("status", "name",)
    date_hierarchy = "date_create"
    list_per_page = 20
    ordering = ("ordering","name",)
    fieldsets = (
        (_('logs admin'), {'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',),}),
        (_('general admin'), {'fields': ('status', 'default'),}),
        (None, {"fields": ("name",),}),
    )
admin.site.register(Category, CategoryAdmin)


class NewsInlineModelForm(AdminModelForm):
    class Meta:
        model = NewsTranslation
class NewsInline(admin.StackedInline):
    model = NewsTranslation
    form = NewsInlineModelForm
    extra = 3
    fields = ('status','language','title','text',)


class NewsAdminForm(AdminModelForm):
    class Meta:
        model =  News
class NewsAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    model = News
    save_on_top = True
    form = NewsAdminForm
    list_display = ('get_status_icon', 'name', 'title', 'event_date','pub_date_begin','pub_date_end','get_categories','get_users','get_edit_icon', 'get_detail_icon', 'get_delete_icon')
    list_display_links = ('name',)
    #list_filter = ("status", "type",'event_date','pub_date_begin','pub_date_end',)
    search_fields = ('name', 'title','event_date','pub_date_begin','pub_date_end',)
    list_per_page = 30
    ordering = ("ordering",)
    fieldsets = (
        (_('logs admin'), {'fields': ('creator', 'date_create','last_modifier', 'date_last_modify',), 'classes': ('collapse',)}),
        (None, {'fields': ('ordering',), 'classes': ('collapse',),}),
        (None, {'fields': ('status','categories',),}),
        (None, {"fields": ('event_date',('pub_date_begin','pub_date_end',),'name','title','small_image','big_image','short_description','text','note'),}),
        (_('Show to'), {'fields': ('users',),}),
    )
    filter_horizontal = ('users','categories',)
    inlines = (NewsInline,)
admin.site.register(News, NewsAdmin)

==> jumbo-news-1.0.tar.gz: jumbo-news-1.0/news/admin.py <==
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from jumbo.admin.options import ExtendibleModelAdmin, OrderedModelAdmin, SettingsAdmin
from jumbo.forms.models import AdminModelForm
from news.models import News, Category, NewsTranslation

class CategoryAdminForm(AdminModelForm):
    class Meta:
        model = Category
class CategoryAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = ('get_status_icon','name','get_edit_icon', 'get_detail_icon', 'get_delete_icon')
    model = Category
    save_on_top = True
    form = CategoryAdminForm
    search_fields = ("status", "name",)
    date_hierarchy = "date_create"
    list_per_page = 20
    ordering = ("ordering","name",)
    fieldsets = (
        (_('logs admin'), {'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',),}),
        (_('general admin'), {'fields': ('status', 'default'),}),
        (None, {"fields": ("name",),}),
    )
admin.site.register(Category, CategoryAdmin)


class NewsInlineModelForm(AdminModelForm):
    class Meta:
        model = NewsTranslation
class NewsInline(admin.StackedInline):
    model = NewsTranslation
    form = NewsInlineModelForm
    extra = 3
    fields = ('status','language','title','text',)


class NewsAdminForm(AdminModelForm):
    class Meta:
        model =  News
class NewsAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    model = News
    save_on_top = True
    form = NewsAdminForm
    list_display = ('get_status_icon', 'force_in_homepage', 'name', 'title', 'event_date',
                    'pub_date_begin','pub_date_end','get_categories','get_users', 
                    'link', 'get_edit_icon', 'get_detail_icon', 'get_delete_icon')
    list_display_links = ('name',)
    #list_filter = ("status", "type",'event_date','pub_date_begin','pub_date_end',)
    search_fields = ('name', 'title','event_date','pub_date_begin','pub_date_end',)
    list_per_page = 30
    ordering = ("ordering",)
    fieldsets = (
        (_('logs admin'), {'fields': ('creator', 'date_create','last_modifier', 'date_last_modify',), 'classes': ('collapse',)}),
        (None, {'fields': ('ordering',), 'classes': ('collapse',),}),
        (None, {'fields': ('status','force_in_homepage', 'categories',),}),
        (None, {"fields": ('event_date',('pub_date_begin','pub_date_end',),'name','title','small_image','big_image','short_description','text','link', 'file','note'),}),
        (_('Show to'), {'fields': ('users',),}),
    )
    filter_horizontal = ('users','categories',)
    inlines = (NewsInline,)
admin.site.register(News, NewsAdmin)
